@@ -197,7 +197,7 @@ def evaluate(feature: dict,
         # record the truth index, provided by genft per mixture.
         tridx = int(feature['mixture_database'][mi]['truth_index']) - 1
         # store index into filename lists in case we want full filenames
-        fnameidx[ni, ti, snri, augi, :] = [ni, ti, tridx, snri, augi]
+        fnameidx[ni, ti, snri, augi,] = [ni, ti, tridx, snri, augi]
 
         # For each mixture, get index endpoint (mix,noise,target sample,...)
         if mi == num_mixtures - 1:
@@ -256,7 +256,7 @@ def evaluate(feature: dict,
         ssnrpk80 = 10 * np.log10(np.percentile(segsnr + 1e-10, 80, interpolation='midpoint'))
 
         # Truth and neural-net prediction data, feature_frames x num_classes
-        truth = feature['truth'][feature['mixture_database'][mi]['o_frame_offset']:fend, :]
+        truth = feature['truth'][feature['mixture_database'][mi]['o_frame_offset']:fend, ]
 
         if len(predict) > 0:
             nno = predict[feature['mixture_database'][mi]['o_frame_offset']:fend]
@@ -271,13 +271,13 @@ def evaluate(feature: dict,
             # mcm2, metrics2, cm2, cmn2, rmse2 = classmetrics(truth, nno, cmode)
 
             # Save all stats, metrics and TN FP FN TP, but only includes for tridx class.
-            mstat[ni, ti, snri, augi, :] = [mi, tsnr, ssnrmean, ssnrmax, ssnrpk80, tgain, *metrics[tridx, :],
-                                            mcm[tridx, 0, 0], mcm[tridx, 0, 1], mcm[tridx, 1, 0], mcm[tridx, 1, 1],
-                                            rmse[tridx]]
-            # metricsall[ni, ti, snri, augi, :, :] = metrics
-            mcmall[ni, ti, snri, augi, :, :, :] = mcm
-            cmall[ni, ti, snri, augi, :, :] = cm
-            # cmnall[ni, ti, snri, augi, :, :] = cmn
+            mstat[ni, ti, snri, augi,] = [mi, tsnr, ssnrmean, ssnrmax, ssnrpk80, tgain, *metrics[tridx,],
+                                          mcm[tridx, 0, 0], mcm[tridx, 0, 1], mcm[tridx, 1, 0], mcm[tridx, 1, 1],
+                                          rmse[tridx]]
+            # metricsall[ni, ti, snri, augi, ] = metrics
+            mcmall[ni, ti, snri, augi,] = mcm
+            cmall[ni, ti, snri, augi,] = cm
+            # cmnall[ni, ti, snri, augi, ] = cmn
 
             # Increment augmentation type
             augi += 1
@@ -298,7 +298,7 @@ def evaluate(feature: dict,
             segsnrex = np.reshape(np.tile(10 * np.log10(segsnr + np.finfo(float).eps), [samples_per_transform, 1]),
                                   len(segsnr) * samples_per_transform,
                                   order='F')
-            feat = feature['feature'][feature['mixture_database'][mi]['o_frame_offset']:fend, :, :]
+            feat = feature['feature'][feature['mixture_database'][mi]['o_frame_offset']:fend, ]
 
             # Truth extension to #samples in this mixture, i.e. MixSubSamples x num_classes
             truthex = np.zeros((len(segsnr) * samples_per_transform, num_classes))
@@ -374,7 +374,7 @@ def evaluate(feature: dict,
                     fti = np.nonzero(truth[:, truth_active[0]])[0][0]
                 else:
                     fti = 0
-                tmp = np.squeeze(feat[fti, :, :])
+                tmp = np.squeeze(feat[fti,])
                 titlestr = 'Example feature, frame {} of size {}x{}'.format(fti, feat.shape[2], feat.shape[1])
             ax3.imshow(np.transpose(tmp), aspect='auto')
             ax3.invert_yaxis()
@@ -407,7 +407,7 @@ def median_filter(x: np.ndarray, n: int) -> np.ndarray:
 
     y = np.zeros((len(x), n), dtype=x.dtype)
     for k in range(len(x)):
-        y[k, :] = pad_x[k:k + n]
+        y[k,] = pad_x[k:k + n]
 
     return np.median(y, axis=1)
 
@@ -479,12 +479,12 @@ def save_eval_report(output_dir, noise_files, target_files, snrs, fnameidx, dfna
     # Total metrics over all data
     metsa, mcmsa, cmsumsa = calculate_metrics(cmall, bmode)  # metric summary all
     metsa_avg = averages(metsa)  # 3 rows: [PPV, TPR, F1, FPR, ACC, TPSUM]
-    metsa_avgwo = averages(metsa[0:-1, :])
+    metsa_avgwo = averages(metsa[0:-1, ])
 
     # Total metrics over all non-special case SNR
-    metsn, mcmsn, cmsumsn = calculate_metrics(cmall[:, :, sridx, :, :, :], bmode)
+    metsn, mcmsn, cmsumsn = calculate_metrics(cmall[:, :, sridx, ], bmode)
     metsn_avg = averages(metsn)  # 3x6
-    metsn_avgwo = averages(metsn[0:-1, :])  # without other (last) class
+    metsn_avgwo = averages(metsn[0:-1, ])  # without other (last) class
 
     # Metric summary by noise and snr per class: 
     # fields: [ACC, TPR, PPV, TNR, FPR, HITFA, F1, MCC, NT, PT, TP, FP]
@@ -495,13 +495,13 @@ def save_eval_report(output_dir, noise_files, target_files, snrs, fnameidx, dfna
     metnsnr_avg = np.zeros((num_noise_files, num_snrs, 3, 6))
     metnsnr_avgwo = np.zeros((num_noise_files, num_snrs, 3, 6))
     for snri in range(num_snrs):
-        metsnr[snri, :, :], _, _ = calculate_metrics(cmall[:, :, snri, :, :, :])
-        metsnr_avg[snri, :, :] = averages(metsnr[snri, :, :])
-        metsnr_avgwo[snri, :, :] = averages(metsnr[snri, 0:-1, :])  # without other class = nclass
+        metsnr[snri,], _, _ = calculate_metrics(cmall[:, :, snri, ])
+        metsnr_avg[snri,] = averages(metsnr[snri,])
+        metsnr_avgwo[snri,] = averages(metsnr[snri, 0:-1, ])  # without other class = nclass
         for ni in range(num_noise_files):
-            metnsnr[ni, snri, :, :], _, _ = calculate_metrics(cmall[ni, :, snri, :, :, :])
-            metnsnr_avg[ni, snri, :, :] = averages(metnsnr[ni, snri, :, :])
-            metnsnr_avgwo[ni, snri, :, :] = averages(metnsnr[ni, snri, 0:-1, :])
+            metnsnr[ni, snri,], _, _ = calculate_metrics(cmall[ni, :, snri, ])
+            metnsnr_avg[ni, snri,] = averages(metnsnr[ni, snri,])
+            metnsnr_avgwo[ni, snri,] = averages(metnsnr[ni, snri, 0:-1, ])
 
     # mcm: [TN FP; FN TP]
     # Fields in mstat, TargetSNR, TargetGain: 
@@ -607,10 +607,10 @@ def save_eval_report(output_dir, noise_files, target_files, snrs, fnameidx, dfna
                 si = tasnridx[snri]  # sorted list
                 f.write('\n')
                 f.write('--- Confusion Matrix for SNR {:3.1f} dB:\n'.format(float(snrs[si])))
-                (met, _, cmsum) = calculate_metrics(cmall[:, :, si, :, :, :])
+                (met, _, cmsum) = calculate_metrics(cmall[:, :, si, ])
                 f.write(format_confusion_matrix(cmsum))
                 f.write('Metric summary:\n')
-                f.write(generate_summary(metsnr[si, :, :]))
+                f.write(generate_summary(metsnr[si,]))
                 f.write('\n\n')
 
     # --------------- Create noise breakdown report --------------------------------
@@ -668,7 +668,7 @@ def save_eval_report(output_dir, noise_files, target_files, snrs, fnameidx, dfna
             f.write('{}\n'.format(np.transpose(snrfloat[tasnridx].astype(int))))
             f.write('{}\n'.format(np.round(metnsnr_avg[ni, tasnridx, 1, 3] * 100, 2)))
             f.write('Confusion Matrix:\n')
-            (_, _, cmsum) = calculate_metrics(cmall[ni, :, :, :, :, :])
+            (_, _, cmsum) = calculate_metrics(cmall[ni,])
             f.write(format_confusion_matrix(cmsum))
             f.write('Noise file full path: {}\n'.format(noise_files[nfileidx[ni]]))
 
