@@ -24,8 +24,6 @@ import json
 from copy import deepcopy
 from os.path import exists
 from os.path import splitext
-from time import gmtime
-from time import strftime
 from typing import List
 from typing import Union
 
@@ -44,15 +42,12 @@ from sonusai.mixture import apply_augmentation
 from sonusai.mixture import build_noise_audio_db
 from sonusai.mixture import build_target_audio_db
 from sonusai.mixture import generate_truth
-from sonusai.mixture import get_class_count
-from sonusai.mixture import get_class_weights_threshold
 from sonusai.mixture import get_mixtures_from_mixid
-from sonusai.mixture import get_next_noise
-from sonusai.mixture import get_noise_audio_from_db
-from sonusai.mixture import get_target_audio_from_db
 from sonusai.mixture import get_total_class_count
+from sonusai.mixture import process_mixture_audio
 from sonusai.utils import human_readable_size
 from sonusai.utils import int16_to_float
+from sonusai.utils import seconds_to_hms
 from sonusai.utils import trim_docstring
 
 
@@ -67,18 +62,16 @@ def genmix(mixdb: dict,
         logger.error('Error processing mixid: {}; resulted in empty list of mixtures'.format(mixid))
         exit()
 
-    class_weights_threshold = get_class_weights_threshold(mixdb_out)
-
     total_samples = sum([sub['samples'] for sub in mixdb_out['mixtures']])
 
     target = np.empty(total_samples, dtype=np.int16)
     noise = np.empty(total_samples, dtype=np.int16)
     truth_t = np.empty((mixdb_out['num_classes'], total_samples), dtype=np.single)
+
+    segsnr = np.empty(0)
+    fft = ForwardTransform(N=mixdb_out['frame_size'] * 4, R=mixdb_out['frame_size'])
     if compute_segsnr:
         segsnr = np.empty(total_samples, dtype=np.single)
-        fft = ForwardTransform(N=mixdb_out['frame_size'] * 4, R=mixdb_out['frame_size'])
-    else:
-        segsnr = np.empty(0)
 
     logger.info('')
     logger.info('Found {} mixtures to process'.format(len(mixdb_out['mixtures'])))
@@ -90,60 +83,22 @@ def genmix(mixdb: dict,
     i_sample_offset = 0
     i_frame_offset = 0
     o_frame_offset = 0
-    for mixture_record in (tqdm(mixdb_out['mixtures'], desc='Processing') if show_progress else mixdb_out['mixtures']):
-        if mixture_record['samples'] % mixdb_out['frame_size'] != 0:
-            logger.error('Number of samples in mixture is not a multiple of {}'.format(mixdb_out['frame_size']))
-            exit()
-
-        target_file_index = mixture_record['target_file_index']
-        target_augmentation = mixdb_out['target_augmentations'][mixture_record['target_augmentation_index']]
-        target_audio = apply_augmentation(audio_in=get_target_audio_from_db(target_audios, target_file_index),
-                                          augmentation=target_augmentation,
-                                          length_common_denominator=mixdb_out['feature_step_samples'],
-                                          dither=mixdb_out['dither'])
-        if len(target_audio) != mixture_record['samples']:
-            logger.error('Number of samples in target does not match database')
-            exit()
-
-        noise_file_index = mixture_record['noise_file_index']
-        noise_augmentation_index = mixture_record['noise_augmentation_index']
-        noise_audio, _ = get_next_noise(offset_in=mixture_record['noise_offset'],
-                                        length=mixture_record['samples'],
-                                        audio_in=get_noise_audio_from_db(noise_audios,
-                                                                         noise_file_index,
-                                                                         noise_augmentation_index))
-
-        mixture_record['i_sample_offset'] = i_sample_offset
-        mixture_record['i_frame_offset'] = i_frame_offset
-        mixture_record['o_frame_offset'] = o_frame_offset
+    for mixture_record in tqdm(mixdb_out['mixtures'], desc='genmix', disable=not show_progress):
+        noise_audio, target_audio = process_mixture_audio(i_frame_offset=i_frame_offset,
+                                                          i_sample_offset=i_sample_offset,
+                                                          o_frame_offset=o_frame_offset,
+                                                          mixdb=mixdb_out,
+                                                          mixture_record=mixture_record,
+                                                          target_audios=target_audios,
+                                                          noise_audios=noise_audios)
 
         audio_indices = slice(i_sample_offset, i_sample_offset + len(target_audio))
-
-        target_audio = np.int16(np.single(target_audio) * mixture_record['target_snr_gain'])
-        noise_audio = np.int16(np.single(noise_audio) * mixture_record['noise_snr_gain'])
-
         target[audio_indices] = target_audio
         noise[audio_indices] = noise_audio
 
-        truth_config = deepcopy(mixdb_out['targets'][mixture_record['target_file_index']]['truth_config'])
-        truth_config['index'] = mixdb_out['targets'][mixture_record['target_file_index']]['truth_index']
-        truth_config['frame_size'] = mixdb_out['frame_size']
-        truth_config['num_classes'] = mixdb_out['num_classes']
-        truth_config['mutex'] = mixdb_out['truth_mutex']
-
-        if mixture_record['target_gain'] == 0:
-            truth = np.zeros((mixdb_out['num_classes'], len(target_audio)), dtype=np.single)
-        else:
-            truth = generate_truth(
-                audio=np.int16(np.single(target_audio) / mixture_record['target_gain']),
-                function=mixdb_out['targets'][mixture_record['target_file_index']]['truth_function'],
-                config=truth_config)
-        truth_t[:, audio_indices] = truth
-
-        mixture_record['class_count'] = get_class_count(
-            truth_index=truth_config['index'],
-            truth=truth,
-            class_weights_threshold=class_weights_threshold)
+        truth_t[:, audio_indices] = generate_truth(mixdb=mixdb_out,
+                                                   mixture_record=mixture_record,
+                                                   target_audio=target_audio)
 
         if compute_segsnr:
             for offset in range(0, mixture_record['samples'], mixdb_out['frame_size']):
@@ -160,9 +115,9 @@ def genmix(mixdb: dict,
 
     mixdb_out['class_count'] = get_total_class_count(mixdb_out)
 
+    duration = len(mixture) / sonusai.mixture.sample_rate
     logger.info('')
-    logger.info(
-        'Duration: {} (HH:MM:SS)'.format(strftime('%H:%M:%S', gmtime(len(mixture) / sonusai.mixture.sample_rate))))
+    logger.info('Duration: {} ([D day[s], ][H]H:MM:SS[.UUUUUU])'.format(seconds_to_hms(seconds=duration)))
     logger.info('mixture:  {}'.format(human_readable_size(mixture.nbytes, 1)))
     logger.info('truth_t:  {}'.format(human_readable_size(truth_t.nbytes, 1)))
 
