@@ -130,8 +130,6 @@ from os.path import join
 from os.path import splitext
 from random import seed
 from random import uniform
-from time import gmtime
-from time import strftime
 
 import numpy as np
 import sox
@@ -147,19 +145,20 @@ from sonusai import logger
 from sonusai import update_console_handler
 from sonusai.mixture import apply_augmentation
 from sonusai.mixture import estimate_audio_length
-from sonusai.mixture import generate_truth
 from sonusai.mixture import get_class_count
 from sonusai.mixture import get_class_weights_threshold
 from sonusai.mixture import get_config_from_file
 from sonusai.mixture import get_next_noise
 from sonusai.mixture import get_total_class_count
 from sonusai.mixture import read_audio
+from sonusai.mixture import truth_function
 from sonusai.utils import expandvars
 from sonusai.utils import human_readable_size
+from sonusai.utils import seconds_to_hms
 from sonusai.utils import trim_docstring
 
 
-def genmixdb(config: dict, show_progress: bool = False) -> dict:
+def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) -> dict:
     required_keys = [
         'class_labels',
         'class_weights_threshold',
@@ -185,10 +184,13 @@ def genmixdb(config: dict, show_progress: bool = False) -> dict:
 
     seed(config['seed'])
 
-    logger.debug('Seed: {}'.format(config['seed']))
-    logger.debug('Configuration:')
-    logger.debug(yaml.dump(config))
+    if logging:
+        logger.debug('Seed: {}'.format(config['seed']))
+        logger.debug('Configuration:')
+        logger.debug(yaml.dump(config))
 
+    if logging:
+        logger.info('Collecting targets')
     targets = get_input_files(config['targets'], cfg={'truth_index':    config['truth_index'],
                                                       'truth_function': config['truth_function'],
                                                       'truth_config':   config['truth_config']})
@@ -196,38 +198,47 @@ def genmixdb(config: dict, show_progress: bool = False) -> dict:
         logger.error('Canceled due to no targets')
         exit()
 
-    logger.debug('List of targets:')
-    logger.debug(yaml.dump([sub['name'] for sub in targets], default_flow_style=False))
+    if logging:
+        logger.debug('List of targets:')
+        logger.debug(yaml.dump([sub['name'] for sub in targets], default_flow_style=False))
 
+    if logging:
+        logger.info('Collecting noises')
     noises = get_input_files(config['noises'])
     if len(noises) == 0:
-        logger.warning('Did not find any noises; using default noise: {}'.format(sonusai.mixture.default_noise))
-        noises = get_input_files([sonusai.mixture.default_noise], silent=True)
-    logger.debug('List of noises:')
-    logger.debug(yaml.dump([sub['name'] for sub in noises], default_flow_style=False))
+        if logging:
+            logger.warning('Did not find any noises; using default noise: {}'.format(sonusai.mixture.default_noise))
+        noises = get_input_files([sonusai.mixture.default_noise])
+    if logging:
+        logger.debug('List of noises:')
+        logger.debug(yaml.dump([sub['name'] for sub in noises], default_flow_style=False))
 
+    if logging:
+        logger.info('Collecting target augmentations')
     target_augmentations = get_augmentations(config['target_augmentations'], target=True)
     expanded_target_augmentations = ''
     for augmentation in target_augmentations:
         expanded_target_augmentations += '- {}\n'.format(augmentation)
-    logger.debug('Expanded list of target augmentations:')
-    logger.debug(expanded_target_augmentations)
+    if logging:
+        logger.debug('Expanded list of target augmentations:')
+        logger.debug(expanded_target_augmentations)
 
+    if logging:
+        logger.info('Collecting noise augmentations')
     noise_augmentations = get_augmentations(config['noise_augmentations'], target=False)
     expanded_noise_augmentations = ''
     for augmentation in noise_augmentations:
         expanded_noise_augmentations += '- {}\n'.format(augmentation)
-    logger.debug('Expanded list of noise augmentations:')
-    logger.debug(expanded_noise_augmentations)
+    if logging:
+        logger.debug('Expanded list of noise augmentations:')
+        logger.debug(expanded_noise_augmentations)
 
     noise_sets = len(noises) * len(noise_augmentations)
     target_sets = len(targets) * len(target_augmentations)
     total_mixtures = noise_sets * target_sets
-    logger.info('')
-    logger.info('Found {} mixtures to process'.format(total_mixtures))
-
-    total_duration = len(noises) * len(noise_augmentations) * \
-                     sum([sub['duration'] for sub in targets]) * len(target_augmentations)
+    if logging:
+        logger.info('')
+        logger.info('Found {} mixtures to process'.format(total_mixtures))
 
     class_weights_threshold = get_class_weights_threshold(config)
 
@@ -257,28 +268,36 @@ def genmixdb(config: dict, show_progress: bool = False) -> dict:
     feature_step_ms = transform_frame_ms * decimation * step
     feature_samples = config['frame_size'] * decimation * stride
     feature_step_samples = config['frame_size'] * decimation * step
+
+    total_duration = 0
+    for duration in [sub['duration'] for sub in targets]:
+        for augmentation in target_augmentations:
+            length = int(duration * sonusai.mixture.sample_rate)
+            if 'tempo' in augmentation:
+                length /= augmentation['tempo']
+            if length % feature_step_samples:
+                length += feature_step_samples - int(length % feature_step_samples)
+            total_duration += float(length) / sonusai.mixture.sample_rate
+    total_duration *= noise_sets
+
     total_samples = total_duration * sonusai.mixture.sample_rate
-    total_features = total_samples / feature_step_samples
 
-    # Feature
-    total_size = total_features * num_bands * stride * sonusai.mixture.float_bytes
-    # Truth
-    total_size += total_features * sonusai.mixture.float_bytes
+    mixture_bytes = total_samples * sonusai.mixture.bit_depth / 8
+    truth_t_bytes = total_samples * config['num_classes'] * sonusai.mixture.float_bytes
+    feature_bytes = total_samples / feature_samples * stride * num_bands * sonusai.mixture.float_bytes
+    truth_f_bytes = total_samples / feature_samples * config['num_classes'] * sonusai.mixture.float_bytes
 
-    mixture_bytes = total_size
-    truth_t_bytes = total_size * config['num_classes'] * 2
-    feature_bytes = total_size / feature_samples * stride * num_bands * 2
-    truth_f_bytes = total_size / feature_samples * config['num_classes'] * 2
-    logger.info('')
-    logger.info('Estimated duration:   {} (HH:MM:SS)'.format(strftime('%H:%M:%S', gmtime(total_duration))))
-    logger.info('Estimated sizes:')
-    logger.info(' mixture:             {}'.format(human_readable_size(mixture_bytes, 1)))
-    logger.info(' truth_t:             {}'.format(human_readable_size(truth_t_bytes, 1)))
-    logger.info(' feature:             {}'.format(human_readable_size(feature_bytes, 1)))
-    logger.info(' truth_f:             {}'.format(human_readable_size(truth_f_bytes, 1)))
-    logger.info('Feature shape:        {} x {} ({} total params)'.format(stride, num_bands, stride * num_bands))
-    logger.info('Feature samples:      {} samples ({} ms)'.format(feature_samples, feature_ms))
-    logger.info('Feature step samples: {} samples ({} ms)'.format(feature_step_samples, feature_step_ms))
+    if logging:
+        logger.info('')
+        logger.info('Estimated duration:   {}'.format(seconds_to_hms(seconds=total_duration)))
+        logger.info('Estimated sizes:')
+        logger.info(' mixture:             {}'.format(human_readable_size(mixture_bytes, 1)))
+        logger.info(' truth_t:             {}'.format(human_readable_size(truth_t_bytes, 1)))
+        logger.info(' feature:             {}'.format(human_readable_size(feature_bytes, 1)))
+        logger.info(' truth_f:             {}'.format(human_readable_size(truth_f_bytes, 1)))
+        logger.info('Feature shape:        {} x {} ({} total params)'.format(stride, num_bands, stride * num_bands))
+        logger.info('Feature samples:      {} samples ({} ms)'.format(feature_samples, feature_ms))
+        logger.info('Feature step samples: {} samples ({} ms)'.format(feature_step_samples, feature_step_ms))
 
     mixdb = {
         'class_count':              [],
@@ -299,12 +318,14 @@ def genmixdb(config: dict, show_progress: bool = False) -> dict:
     }
 
     # Read in all audio data beforehand to avoid reading it multiple times in the loop
-    logger.debug('Reading noise audio')
+    if logging:
+        logger.debug('Reading noise audio')
     raw_noise_audio = []
     for noise in noises:
         raw_noise_audio.append(read_audio(name=noise['name'], dither=config['dither']))
 
-    logger.debug('Reading target audio')
+    if logging:
+        logger.debug('Reading target audio')
     raw_target_audio = []
     for target in targets:
         raw_target_audio.append(read_audio(name=target['name'], dither=config['dither']))
@@ -351,7 +372,7 @@ def genmixdb(config: dict, show_progress: bool = False) -> dict:
             length_common_denominator=1,
             dither=config['dither'])
 
-        desc = 'Processing {} of {}'.format(n_id + 1, len(mixtures))
+        desc = 'genmixdb {} of {}'.format(n_id + 1, len(mixtures))
         mixtures[n_id] = p_map(partial(process_mixture,
                                        config=config,
                                        targets=targets,
@@ -362,7 +383,8 @@ def genmixdb(config: dict, show_progress: bool = False) -> dict:
                                        truth_mutex=truth_mutex,
                                        class_weights_threshold=class_weights_threshold),
                                mixtures[n_id],
-                               desc=desc)
+                               desc=desc,
+                               disable=not show_progress)
 
     # Flatten mixtures
     mixdb['mixtures'] = [item for sublist in mixtures for item in sublist]
@@ -374,26 +396,21 @@ def genmixdb(config: dict, show_progress: bool = False) -> dict:
     truth_t_bytes = total_samples * config['num_classes'] * 4
     feature_bytes = total_samples / feature_samples * stride * num_bands * 4
     truth_f_bytes = total_samples / feature_samples * config['num_classes'] * 4
-    logger.info('')
-    logger.info('Actual duration: {} (HH:MM:SS)'.format(strftime('%H:%M:%S', gmtime(total_duration))))
-    logger.info('Actual sizes:')
-    logger.info(' mixture:        {}'.format(human_readable_size(mixture_bytes, 1)))
-    logger.info(' truth_t:        {}'.format(human_readable_size(truth_t_bytes, 1)))
-    logger.info(' feature:        {}'.format(human_readable_size(feature_bytes, 1)))
-    logger.info(' truth_f:        {}'.format(human_readable_size(truth_f_bytes, 1)))
+    if logging:
+        logger.info('')
+        logger.info('Actual duration: {}'.format(seconds_to_hms(seconds=total_duration)))
+        logger.info('Actual sizes:')
+        logger.info(' mixture:        {}'.format(human_readable_size(mixture_bytes, 1)))
+        logger.info(' truth_t:        {}'.format(human_readable_size(truth_t_bytes, 1)))
+        logger.info(' feature:        {}'.format(human_readable_size(feature_bytes, 1)))
+        logger.info(' truth_f:        {}'.format(human_readable_size(truth_f_bytes, 1)))
 
     return mixdb
 
 
-def get_input_files(records, cfg=None, silent=False):
+def get_input_files(records, cfg=None):
     if cfg is None:
-        desc = 'noises'
         cfg = {}
-    else:
-        desc = 'targets'
-
-    if not silent:
-        logger.info('Collecting {}'.format(desc))
 
     files = []
     for record in records:
@@ -426,7 +443,8 @@ def append_input_files(files: list, in_record, cfg: dict, tokens=None):
     tokens.update(new_tokens)
     names = glob(in_name)
     if not names:
-        logger.warning('Could not find {}. Make sure path exists'.format(in_name))
+        logger.error('Could not find {}. Make sure path exists'.format(in_name))
+        exit()
     for name in names:
         ext = splitext(name)[1].lower()
         dir_name = dirname(name)
@@ -475,11 +493,6 @@ def append_input_files(files: list, in_record, cfg: dict, tokens=None):
 
 
 def get_augmentations(rules: list, target: bool) -> list:
-    if target:
-        desc = 'target augmentations'
-    else:
-        desc = 'noise augmentations'
-    logger.info('Collecting {}'.format(desc))
     augmentations = []
     for rule in rules:
         expand_augmentations(augmentations, rule, target)
@@ -655,12 +668,6 @@ def process_mixture(mixture: dict,
                 mixture['target_snr_gain'] = 1
                 mixture['noise_snr_gain'] = noise_gain
 
-    truth_config = deepcopy(target['truth_config'])
-    truth_config['index'] = target['truth_index']
-    truth_config['frame_size'] = config['frame_size']
-    truth_config['num_classes'] = config['num_classes']
-    truth_config['mutex'] = truth_mutex
-
     # Check for clipping in mixture
     mixture_audio = np.single(augmented_target_audio) * mixture['target_snr_gain'] + \
                     np.single(noise_segment) * mixture['noise_snr_gain']
@@ -672,12 +679,18 @@ def process_mixture(mixture: dict,
         mixture['noise_snr_gain'] *= gain_adjustment
         target_gain *= gain_adjustment
 
+    truth_config = deepcopy(target['truth_config'])
+    truth_config['index'] = target['truth_index']
+    truth_config['frame_size'] = config['frame_size']
+    truth_config['num_classes'] = config['num_classes']
+    truth_config['mutex'] = truth_mutex
+
     if target_gain == 0:
         truth = np.zeros((config['num_classes'], len(augmented_target_audio)), dtype=np.int16)
     else:
         augmented_target_audio = np.int16(
             np.single(augmented_target_audio) * mixture['target_snr_gain'])
-        truth = generate_truth(
+        truth = truth_function(
             audio=np.int16(np.single(augmented_target_audio) / target_gain),
             function=target['truth_function'],
             config=truth_config)
