@@ -111,7 +111,7 @@ def gentcst(fold: str = '*',
 
     config['targets'] = []
 
-    logger.info('Processing {} entries in tree'.format(len(use_files)))
+    logger.info('gentcst {} entries in tree'.format(len(use_files)))
     for file in use_files:
         local_config = {}
         local_name = dirname(file['file']) + '/config.yml'
