@@ -1,8 +1,12 @@
+from copy import deepcopy
+
 import numpy as np
 from pyaaware import ForwardTransform
 from pyaaware import SED
 
 from sonusai import logger
+from sonusai.mixture import get_class_count
+from sonusai.mixture import get_class_weights_threshold
 from sonusai.utils import int16_to_float
 
 
@@ -10,7 +14,30 @@ def strictly_decreasing(list_to_check: list) -> bool:
     return all(x > y for x, y in zip(list_to_check, list_to_check[1:]))
 
 
-def generate_truth(audio: np.ndarray, function: str, config: dict) -> np.ndarray:
+def generate_truth(mixdb: dict, mixture_record: dict, target_audio: np.ndarray) -> np.ndarray:
+    truth_config = deepcopy(mixdb['targets'][mixture_record['target_file_index']]['truth_config'])
+    truth_config['index'] = mixdb['targets'][mixture_record['target_file_index']]['truth_index']
+    truth_config['frame_size'] = mixdb['frame_size']
+    truth_config['num_classes'] = mixdb['num_classes']
+    truth_config['mutex'] = mixdb['truth_mutex']
+
+    if mixture_record['target_gain'] == 0:
+        truth = np.zeros((mixdb['num_classes'], len(target_audio)), dtype=np.single)
+    else:
+        truth = truth_function(
+            audio=np.int16(np.single(target_audio) / mixture_record['target_gain']),
+            function=mixdb['targets'][mixture_record['target_file_index']]['truth_function'],
+            config=truth_config)
+
+    mixture_record['class_count'] = get_class_count(
+        truth_index=truth_config['index'],
+        truth=truth,
+        class_weights_threshold=get_class_weights_threshold(mixdb))
+
+    return truth
+
+
+def truth_function(audio: np.ndarray, function: str, config: dict) -> np.ndarray:
     required_parameters = ['index', 'frame_size', 'num_classes', 'mutex']
     for parameter in required_parameters:
         if parameter not in config.keys():
